Learn R Programming

GJRM.data (version 0.1-1)

hie: Hiring Incentive Experiment - HIE

Description

Full description available at the web link below.

Usage

data(hie)

Arguments

Format

hie is a 7734 row data frame with the following columns:

agree

Equal to 1 if the individual is in the HIE group and agreed to participate, and 0 if the individual is assigned to the control group or refuses to participate.

bonus

Random allocation variable equal to 1 if the individual/employer was assigned to the hiring incentive experiment group and 0 to the control group. This is the IV.

benefit

Weekly benefit amount + dependents' allowance.

unemp.dur

Weeks of benefits.

status

Equal to 1 if unemp.dur < 26 and 0 otherwise.

age

Age of claimant.

gender

1 = male and 0 = female.

ethnicity

1 = black and 0 otherwise.

prearn

Claimant's pre-claim earnings.