Full description available at the web link below.
data(hie)hie is a 7734 row data frame with the following columns:
Equal to 1 if the individual is in the HIE group and agreed to participate, and 0 if the individual is assigned to the control group or refuses to participate.
Random allocation variable equal to 1 if the individual/employer was assigned to the hiring incentive experiment group and 0 to the control group. This is the IV.
Weekly benefit amount + dependents' allowance.
Weeks of benefits.
Equal to 1 if unemp.dur < 26 and 0 otherwise.
Age of claimant.
1 = male and 0 = female.
1 = black and 0 otherwise.
Claimant's pre-claim earnings.